{ config, lib, pkgs, ... }:

let mainUserHome = "/home/palo";
in {

  # grub configuration
  # ------------------
  boot.loader.grub = {
    device = "/dev/sda";
    enable = true;
    version = 2;
  };

  # lvm volume group
  # ----------------
  boot.initrd.luks.devices = {
    vg = {
      device = "/dev/sda2";
      preLVM = true;
    };
  };

  # NTFS support
  # ------------
  environment.systemPackages = [ pkgs.ntfs3g ];

  # root
  # ----
  fileSystems."/" = {
    options = [ "noatime" "nodiratime" "discard" ];
    device = "/dev/vg/root";
    fsType = "ext4";
  };

  # boot
  # ----
  fileSystems."/boot" = {
    device = "/dev/sda1";
    fsType = "ext4";
  };

  # home
  # ----
  fileSystems."/home" = {
    options = [ "noatime" "nodiratime" ];
    device = "/dev/mapper/decrypted_home";
    fsType = "ext4";
    encrypted = {
      enable = true;
      keyFile = "/mnt-root/root/keys/home.key";
      label = "decrypted_home";
      blkDev = "/dev/mapper/store-home";
    };
  };

  # var/lib/docker
  # --------------
  fileSystems."/var/lib/docker" = {
    options = [ "noatime" "nodiratime" ];
    device = "/dev/mapper/decrypted_docker";
    fsType = "ext4";
    encrypted = {
      enable = true;
      keyFile = "/mnt-root/root/keys/docker.key";
      label = "decrypted_docker";
      blkDev = "/dev/mapper/store-docker";
    };
  };

  imports = [
    # automount
    # ---------
    (let mediaUUID = "b8ba192e-e2aa-47dd-85ec-dcf97ec9310a";
    in {
      fileSystems."/media" = {
        device = "/dev/disk/by-uuid/${mediaUUID}";
        fsType = "ext4";
        options = [
          "nofail"
          "noauto"
          #"x-systemd.device-timeout=1ms"
        ];
      };
      systemd.mounts = [{
        enable = true;
        options = "nofail,noauto";
        type = "ext4";
        wantedBy = [ "multi-user.target" ];
        what = "/dev/disk/by-uuid/${mediaUUID}";
        where = "/media";
      }];
    })

    (let backupUUID = "f7fa1c0e-ac9f-4955-b4bd-644c1ddb0d89";
    in {
      fileSystems."/backup" = {
        device = "/dev/disk/by-uuid/${backupUUID}";
        fsType = "ext4";
        options = [
          "nofail"
          "noauto"
          #"x-systemd.device-timeout=1ms"
        ];
      };
      systemd.mounts = [{
        enable = true;
        options = "nofail,noauto";
        type = "ext4";
        wantedBy = [ "multi-user.target" ];
        what = "/dev/disk/by-uuid/${backupUUID}";
        where = "/backup";
      }];
    })
  ];

}

